@@ -2,12 +2,11 @@ import logging
 
 from django.contrib import admin
 
-from . import __title__
 from ...admin import ServicesUserAdmin
+from . import __title__
 from .models import DiscordUser
 from .utils import LoggerAddTag
 
-
 logger = LoggerAddTag(logging.getLogger(__name__), __title__)
 
 
@@ -18,21 +17,16 @@ class DiscordUserAdmin(ServicesUserAdmin):
     list_filter = ServicesUserAdmin.list_filter + ('activated',)
     ordering = ('-activated',)
 
-    def _uid(self, obj):
-        return obj.uid
-
-    _uid.short_description = 'Discord ID (UID)'
-    _uid.admin_order_field = 'uid'
-
-    def _username(self, obj):
-        if obj.username and obj.discriminator:
-            return f'{obj.username}#{obj.discriminator}'
-        else:
-            return ''
-
     def delete_queryset(self, request, queryset):
         for user in queryset:
             user.delete_user()
 
-    _username.short_description = 'Discord Username'
-    _username.admin_order_field = 'username'
+    @admin.display(description='Discord ID (UID)', ordering='uid')
+    def _uid(self, obj):
+        return obj.uid
+
+    @admin.display(description='Discord Username', ordering='username')
+    def _username(self, obj):
+        if obj.username and obj.discriminator:
+            return f'{obj.username}#{obj.discriminator}'
+        return ''
