@@ -15,5 +15,5 @@ class Ips4User(models.Model):
 
     class Meta:
         permissions = (
-            ("access_ips4", u"Can access the IPS4 service"),
+            ("access_ips4", "Can access the IPS4 service"),
         )
