@@ -20,7 +20,7 @@ ACCESS_PERM = 'ips4.access_ips4'
 def activate_ips4(request):
     logger.debug("activate_ips4 called by user %s" % request.user)
     character = request.user.profile.main_character
-    logger.debug("Adding IPS4 user for user %s with main character %s" % (request.user, character))
+    logger.debug(f"Adding IPS4 user for user {request.user} with main character {character}")
     result = Ips4Manager.add_user(Ips4Tasks.get_username(request.user), request.user.email)
     # if empty we failed
     if result[0] != "" and not Ips4Tasks.has_account(request.user):
@@ -33,8 +33,7 @@ def activate_ips4(request):
             'username': result[0],
             'password': result[1],
         }
-        return render(request, 'services/service_credentials.html',
-                      context={'credentials': credentials, 'service': 'IPSuite4'})
+        return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'IPSuite4'})
     else:
         logger.error("Unsuccessful attempt to activate IPS4 for user %s" % request.user)
         messages.error(request, _('An error occurred while processing your IPSuite4 account.'))
@@ -55,8 +54,7 @@ def reset_ips4_password(request):
                 'username': request.user.ips4.username,
                 'password': result,
             }
-            return render(request, 'services/service_credentials.html',
-                          context={'credentials': credentials, 'service': 'IPSuite4'})
+            return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'IPSuite4'})
 
     logger.error("Unsuccessful attempt to reset IPS4 password for user %s" % request.user)
     messages.error(request, _('An error occurred while processing your IPSuite4 account.'))
@@ -102,4 +100,3 @@ def deactivate_ips4(request):
         logger.error("Unsuccessful attempt to deactivate IPS4 for user %s" % request.user)
         messages.error(request, _('An error occurred while processing your IPSuite4 account.'))
     return redirect("services:services")
-
