@@ -24,7 +24,7 @@ ACCESS_PERM = 'openfire.access_openfire'
 def activate_jabber(request):
     logger.debug("activate_jabber called by user %s" % request.user)
     character = request.user.profile.main_character
-    logger.debug("Adding jabber user for user %s with main character %s" % (request.user, character))
+    logger.debug(f"Adding jabber user for user {request.user} with main character {character}")
     info = OpenfireManager.add_user(OpenfireTasks.get_username(request.user))
     # If our username is blank means we already had a user
     if info[0] != "":
@@ -37,8 +37,7 @@ def activate_jabber(request):
             'username': info[0],
             'password': info[1],
         }
-        return render(request, 'services/service_credentials.html',
-                      context={'credentials': credentials, 'service': 'Jabber'})
+        return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'Jabber'})
     else:
         logger.error("Unsuccessful attempt to activate jabber for user %s" % request.user)
         messages.error(request, _('An error occurred while processing your jabber account.'))
@@ -72,8 +71,7 @@ def reset_jabber_password(request):
                 'username': request.user.openfire.username,
                 'password': result,
             }
-            return render(request, 'services/service_credentials.html',
-                          context={'credentials': credentials, 'service': 'Jabber'})
+            return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'Jabber'})
     logger.error("Unsuccessful attempt to reset jabber for user %s" % request.user)
     messages.error(request, _('An error occurred while processing your jabber account.'))
     return redirect("services:services")
@@ -97,21 +95,19 @@ def jabber_broadcast_view(request):
         logger.debug("Received POST request containing form, valid: %s" % form.is_valid())
         if form.is_valid():
             main_char = request.user.profile.main_character
-            logger.debug("Processing jabber broadcast for user %s with main character %s" % (request.user, main_char))
+            logger.debug(f"Processing jabber broadcast for user {request.user} with main character {main_char}")
             try:
                 if main_char is not None:
-                    message_to_send = form.cleaned_data[
-                                          'message'] + "\n##### SENT BY: " + "[" + main_char.corporation_ticker + "]" + \
-                                      main_char.character_name + " TO: " + \
-                                      form.cleaned_data['group'] + " WHEN: " + datetime.datetime.utcnow().strftime(
-                        "%Y-%m-%d %H:%M:%S") + " #####\n##### Replies are NOT monitored #####\n"
+                    message_to_send = form.cleaned_data['message'] + "\n##### SENT BY: " + "[" + main_char.corporation_ticker + "]" + \
+                                        main_char.character_name + " TO: " + \
+                                        form.cleaned_data['group'] + " WHEN: " + datetime.datetime.utcnow().strftime(
+                                            "%Y-%m-%d %H:%M:%S") + " #####\n##### Replies are NOT monitored #####\n"
                     group_to_send = form.cleaned_data['group']
 
                 else:
-                    message_to_send = form.cleaned_data[
-                        'message'] + "\n##### SENT BY: " + "No character but can send pings?" + " TO: " + \
-                        form.cleaned_data['group'] + " WHEN: " + datetime.datetime.utcnow().strftime(
-                        "%Y-%m-%d %H:%M:%S") + " #####\n##### Replies are NOT monitored #####\n"
+                    message_to_send = form.cleaned_data['message'] + "\n##### SENT BY: " + "No character but can send pings?" + " TO: " + \
+                                        form.cleaned_data['group'] + " WHEN: " + datetime.datetime.utcnow().strftime(
+                                            "%Y-%m-%d %H:%M:%S") + " #####\n##### Replies are NOT monitored #####\n"
                     group_to_send = form.cleaned_data['group']
 
                 OpenfireManager.send_broadcast_message(group_to_send, message_to_send)
@@ -124,7 +120,7 @@ def jabber_broadcast_view(request):
     else:
         form = JabberBroadcastForm()
         form.fields['group'].choices = allchoices
-        logger.debug("Generated broadcast form for user %s containing %s groups" % (
+        logger.debug("Generated broadcast form for user {} containing {} groups".format(
             request.user, len(form.fields['group'].choices)))
 
     context = {'form': form}
