@@ -1,6 +1,7 @@
 import logging
 
 from django.contrib import messages
+from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.auth.decorators import login_required, permission_required
 from django.shortcuts import render, redirect
 from django.conf import settings
@@ -23,7 +24,7 @@ def activate_teamspeak3(request):
 
     character = request.user.profile.main_character
     with Teamspeak3Manager() as ts3man:
-        logger.debug("Adding TS3 user for user %s with main character %s" % (request.user, character))
+        logger.debug(f"Adding TS3 user for user {request.user} with main character {character}")
         result = ts3man.add_user(request.user, Teamspeak3Tasks.get_username(request.user))
 
     # if its empty we failed
@@ -55,8 +56,7 @@ def verify_teamspeak3(request):
         form = TeamspeakJoinForm(initial={'username': request.user.teamspeak3.uid})
     context = {
         'form': form,
-        'authinfo': {'teamspeak3_uid': request.user.teamspeak3.uid,
-                     'teamspeak3_perm_key': request.user.teamspeak3.perm_key},
+        'authinfo': {'teamspeak3_uid': request.user.teamspeak3.uid, 'teamspeak3_perm_key': request.user.teamspeak3.perm_key},
         'public_url': settings.TEAMSPEAK3_PUBLIC_URL,
     }
     return render(request, 'services/teamspeak3/teamspeakjoin.html', context=context)
@@ -99,3 +99,11 @@ def reset_teamspeak3_perm(request):
         logger.error("Unsuccessful attempt to reset TS3 permission key for user %s" % request.user)
         messages.error(request, _('An error occurred while processing your TeamSpeak3 account.'))
     return redirect("services:services")
+
+
+@login_required
+@staff_member_required
+def admin_update_ts3_groups(request):
+    Teamspeak3Tasks.run_ts3_group_update.delay()
+    messages.info(request, "Started updating TS3 server groups...")
+    return redirect("admin:teamspeak3_authts_changelist")
