@@ -21,7 +21,7 @@ ACCESS_PERM = 'xenforo.access_xenforo'
 def activate_xenforo_forum(request):
     logger.debug("activate_xenforo_forum called by user %s" % request.user)
     character = request.user.profile.main_character
-    logger.debug("Adding XenForo user for user %s with main character %s" % (request.user, character))
+    logger.debug(f"Adding XenForo user for user {request.user} with main character {character}")
     result = XenForoManager.add_user(XenforoTasks.get_username(request.user), request.user.email)
     # Based on XenAPI's response codes
     if result['response']['status_code'] == 200:
@@ -33,7 +33,7 @@ def activate_xenforo_forum(request):
             'password': result['password'],
         }
         return render(request, 'services/service_credentials.html',
-                      context={'credentials': credentials, 'service': 'XenForo'})
+                        context={'credentials': credentials, 'service': 'XenForo'})
 
     else:
         logger.error("Unsuccessful attempt to activate xenforo for user %s" % request.user)
@@ -68,7 +68,7 @@ def reset_xenforo_password(request):
                 'password': result['password'],
             }
             return render(request, 'services/service_credentials.html',
-                          context={'credentials': credentials, 'service': 'XenForo'})
+                        context={'credentials': credentials, 'service': 'XenForo'})
     logger.error("Unsuccessful attempt to reset XenForo password for user %s" % request.user)
     messages.error(request, _('An error occurred while processing your XenForo account.'))
     return redirect("services:services")
